package fr.itsonus.bousoleplussbackend.infrastructure.postgres.repositories;

import fr.itsonus.bousoleplussbackend.domain.quiz.model.Question;
import fr.itsonus.bousoleplussbackend.domain.quiz.spi.QuestionCacheRepository;
import fr.itsonus.bousoleplussbackend.infrastructure.postgres.models.PostgresQuestionDto;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Service;

import java.util.HashSet;
import java.util.List;
import java.util.Set;
import java.util.stream.Collectors;

@Service
@AllArgsConstructor
public class QuestionCacheProxyRepository implements QuestionCacheRepository {

    private final QuestionCachePostgresRepository questionCachePostgresRepository;

    public List<Question> findQuestions(Long axeId, Long bundleId) {
        return questionCachePostgresRepository.findAllByAxeIdAndBundleIdOrderByIndexAsc(axeId, bundleId)
                .stream()
                .map(PostgresQuestionDto::toQuestion).collect(Collectors.toList());
    }

    public List<Question> findDefaultQuestions() {
        return questionCachePostgresRepository.findAllByBundleIsNull()
                .stream()
                .map(PostgresQuestionDto::toQuestion).collect(Collectors.toList());
    }

    public List<Question> findDefaultQuestions(Long axeId) {
        return questionCachePostgresRepository.findAllByAxeIdAndBundleIsNullOrderByIndexAsc(axeId)
                .stream()
                .map(PostgresQuestionDto::toQuestion).collect(Collectors.toList());
    }

    @Override
    public List<Question> findAllByAxeId(Long axeId) {
        var questions = questionCachePostgresRepository.findAllByAxeIdAndBundleIsNotNullOrderByIndexAsc(axeId)
                .stream()
                .map(PostgresQuestionDto::toQuestion).toList();
        Set<String> set = new HashSet<>(questions.size());
        return questions.stream().filter(q -> set.add(q.getLabel() + q.getDescription())).collect(Collectors.toList());
    }
}
