import {defineStore} from 'pinia';

export interface Bundle {
  id: number;
  label: string;
  lastQuizzDate: string;
  numberOfQuizzes: number;
}

export interface QuestionCreation {
  label: string;
  description: string;
  axeId: number;
  index: number;
}

export interface BundleCreationRequest {
  label: string;
  questions: QuestionCreation[];
}

export const useBundleStore = defineStore('bundle', {
  state: () => ({
    selectedBundle: ref<number>(useCookie('bundleId').value),
  }),
  actions: {

    findAll(): Bundle[] {
      return useApi("bundles");
    },

    setCurrentBundle(bundle: Bundle) {
      this.selectedBundle = bundle.id;
      useCookie('bundleId').value = bundle.id;
    },

    create(request: BundleCreationRequest) {
      return useApi("bundles", {
        method: "POST",
        body: request
      });
    }
  }
});
